@@ -141,13 +141,17 @@ def pbn_latex_deal(pbn, cards="NESW", ll="", ul="", ur=""):
     for card in "NESW":
         if card not in cards:
             if card == "N":
-                all["north"] = empty_hand
+                # all["north"] = empty_hand
+                # use space can hide the cell
+                all["north"] = ""
             if card == "W":
                 all["west"] = empty_hand
             if card == "E":
                 all["east"] = empty_hand
             if card == "S":
-                all["south"] = empty_hand
+                #all["south"] = empty_hand
+                # use space can hide the cell
+                all["south"] = ""
 
     if ul == "":
         all["ul"] = latex_info(tags["Dealer"] + "/" + tags["Vulnerable"])
